@@ -147,36 +147,39 @@ class OpenEuler():
 
     def __replace_macros(self,value, macros):
         """根据宏字典替换字符串中的宏."""
-        original_value = value
-        while True:
-            for key, val in macros.items():
-                value = re.sub(r'%\{' + re.escape(key) + r'\}', val, value)
-            if value == original_value:
-                break
-            original_value = value
-        return value
+        if not macros:
+            return value
+
+            # 预编译所有宏的正则表达式，提升效率
+        patterns = [
+            (re.compile(re.escape(key)), val)
+            for key, val in macros.items()
+        ]
+
+        prev_value = None
+        current_value = value
+        # 循环替换直到无变化（处理嵌套宏）
+        while current_value != prev_value:
+            prev_value = current_value
+            for pattern, replacement in patterns:
+                current_value = pattern.sub(replacement, current_value)
+        return current_value
+
 
     def __extract_macros(self,spec):
-        macros = {}
-        for key, value in spec.macros.items():
-            macros[key] = value
-        if "name" not in macros.keys():
-            macros['name'] = spec.name
-        if "version" not in macros.keys():
-            macros['version'] = spec.version
-        if "release" not in macros.keys():
-            macros['release'] = spec.release
-        for k, w in DEFAULT_MACROS.items():
-            if k not in macros.keys():
-                macros[k] = w
+        macros = dict(spec.macros)
+
+        # 补充必要的默认宏（若不存在）
+        macros.setdefault("name", spec.name)
+        macros.setdefault("version", spec.version)
+        macros.setdefault("release", spec.release)
+
+        # 补充全局默认宏（若不存在）
+        for key, default_val in DEFAULT_MACROS.items():
+            macros.setdefault(key, default_val)
+
         return macros
 
-    def __get_spec_files(self,root_path):
-        spec_files = []
-        for elem in Path(root_path).glob("**/*"):
-            if Path(elem).is_file() and elem.name.endswith(".spec"):
-                spec_files.append(elem)
-        return spec_files
 
     def __get_rpm_list_from_spec(self,spec_file):
         """从 RPM spec 文件中提取所有包名并替换宏。"""
@@ -201,7 +204,7 @@ class OpenEuler():
         with tempfile.TemporaryDirectory() as temp_dir:
             git.Repo.clone_from(repo_url, temp_dir, branch=branch, depth=1)
             log.info(f"clone {repo_name} success")
-            spec_files = self.__get_spec_files(temp_dir)
+            spec_files = list(Path(temp_dir).rglob("*.spec"))
 
             for spec_file in spec_files:
                 temp_list = self.__get_rpm_list_from_spec(spec_file)
